==> qtjambi-websockets-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiWebSockets/QWebSocketHandshakeOptions_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebSockets/qwebsockethandshakeoptions.h>
#include <QtCore/QVariant>
#include <QtCore/QStringList>

#include <QtJambi/QtJambiAPI>
#include <QtJambiWebSockets/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebSocketHandshakeOptions(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebSocketHandshakeOptions")
    QWebSocketHandshakeOptions *_ptr = reinterpret_cast<QWebSocketHandshakeOptions *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebSocketHandshakeOptions()
void __qt_construct_QWebSocketHandshakeOptions_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebSocketHandshakeOptions()")
    Q_UNUSED(__java_arguments)
    QWebSocketHandshakeOptions *__qt_this = new(__qtjambi_ptr) QWebSocketHandshakeOptions();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QWebSocketHandshakeOptions(QWebSocketHandshakeOptions)
void __qt_construct_QWebSocketHandshakeOptions_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebSocketHandshakeOptions(QWebSocketHandshakeOptions)")
    jobject other0 = __java_arguments[0].l;
    const QWebSocketHandshakeOptions& __qt_other0 = qtjambi_cast<const QWebSocketHandshakeOptions& >(__jni_env, other0);
    QWebSocketHandshakeOptions *__qt_this = new(__qtjambi_ptr) QWebSocketHandshakeOptions(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QWebSocketHandshakeOptions
void __qt_destruct_QWebSocketHandshakeOptions(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebSocketHandshakeOptions")
    reinterpret_cast<QWebSocketHandshakeOptions*>(ptr)->~QWebSocketHandshakeOptions();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebSocketHandshakeOptions::QWebSocketHandshakeOptions()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_initialize_1native__Lio_qt_websockets_QWebSocketHandshakeOptions_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebSocketHandshakeOptions::QWebSocketHandshakeOptions()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebSocketHandshakeOptions_0, sizeof(QWebSocketHandshakeOptions), typeid(QWebSocketHandshakeOptions), false, &deleter_QWebSocketHandshakeOptions, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketHandshakeOptions::QWebSocketHandshakeOptions(QWebSocketHandshakeOptions)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_initialize_1native__Lio_qt_websockets_QWebSocketHandshakeOptions_2Lio_qt_websockets_QWebSocketHandshakeOptions_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebSocketHandshakeOptions::QWebSocketHandshakeOptions(QWebSocketHandshakeOptions)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebSocketHandshakeOptions_1, sizeof(QWebSocketHandshakeOptions), typeid(QWebSocketHandshakeOptions), false, &deleter_QWebSocketHandshakeOptions, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketHandshakeOptions::operator=(QWebSocketHandshakeOptions)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_assign_1native_1cref_1QWebSocketHandshakeOptions__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketHandshakeOptions::operator=(QWebSocketHandshakeOptions)", __qt_this)
        const QWebSocketHandshakeOptions& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QWebSocketHandshakeOptions>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketHandshakeOptions::operator==(QWebSocketHandshakeOptions,QWebSocketHandshakeOptions)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_operator_1equal_1native_1cref_1QWebSocketHandshakeOptions__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketHandshakeOptions::operator==(QWebSocketHandshakeOptions,QWebSocketHandshakeOptions)", __qt_this)
        const QWebSocketHandshakeOptions& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QWebSocketHandshakeOptions>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebSocketHandshakeOptions::setSubprotocols(QStringList)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_setSubprotocols_1native_1cref_1QStringList__JLjava_util_Collection_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject protocols0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketHandshakeOptions::setSubprotocols(QStringList)", __qt_this)
        const QStringList&  __qt_protocols0 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, protocols0);
        __qt_this->setSubprotocols(__qt_protocols0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketHandshakeOptions::subprotocols()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_subprotocols_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketHandshakeOptions::subprotocols()const", __qt_this)
        QStringList __qt_return_value = __qt_this->subprotocols();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebSocketHandshakeOptions::swap(QWebSocketHandshakeOptions&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_swap_1native_1ref_1QWebSocketHandshakeOptions__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketHandshakeOptions::swap(QWebSocketHandshakeOptions&)", __qt_this)
        QWebSocketHandshakeOptions& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWebSocketHandshakeOptions>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebSocketHandshakeOptions(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebSocketHandshakeOptions>("QWebSocketHandshakeOptions", "io/qt/websockets/QWebSocketHandshakeOptions");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebSocketHandshakeOptions, {
        ConstructorInfo(&__qt_construct_QWebSocketHandshakeOptions_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QWebSocketHandshakeOptions_1, "Lio/qt/websockets/QWebSocketHandshakeOptions;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebSocketHandshakeOptions);
    registerMetaType<QWebSocketHandshakeOptions>("QWebSocketHandshakeOptions");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-websockets-debuginfo-linux-x64-6.5.8.jar: sources/QtJambiWebSockets/QWebSocketHandshakeOptions_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebSockets/qwebsockethandshakeoptions.h>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiWebSockets/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebSocketHandshakeOptions(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebSocketHandshakeOptions")
    QWebSocketHandshakeOptions *_ptr = reinterpret_cast<QWebSocketHandshakeOptions *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebSocketHandshakeOptions()
void __qt_construct_QWebSocketHandshakeOptions(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebSocketHandshakeOptions()")
    Q_UNUSED(__java_arguments)
    QWebSocketHandshakeOptions *__qt_this = new(__qtjambi_ptr) QWebSocketHandshakeOptions();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QWebSocketHandshakeOptions::QWebSocketHandshakeOptions()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_initialize_1native__Lio_qt_websockets_QWebSocketHandshakeOptions_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebSocketHandshakeOptions::QWebSocketHandshakeOptions()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebSocketHandshakeOptions, sizeof(QWebSocketHandshakeOptions), typeid(QWebSocketHandshakeOptions), 0, false, &deleter_QWebSocketHandshakeOptions, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QWebSocketHandshakeOptions(QWebSocketHandshakeOptions)
void __qt_construct_QWebSocketHandshakeOptions_cref_QWebSocketHandshakeOptions(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebSocketHandshakeOptions(QWebSocketHandshakeOptions)")
    jobject other0 = __java_arguments[0].l;
    const QWebSocketHandshakeOptions& __qt_other0 = qtjambi_cast<const QWebSocketHandshakeOptions&>(__jni_env, other0);
    QWebSocketHandshakeOptions *__qt_this = new(__qtjambi_ptr) QWebSocketHandshakeOptions(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QWebSocketHandshakeOptions::QWebSocketHandshakeOptions(QWebSocketHandshakeOptions)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_initialize_1native__Lio_qt_websockets_QWebSocketHandshakeOptions_2Lio_qt_websockets_QWebSocketHandshakeOptions_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebSocketHandshakeOptions::QWebSocketHandshakeOptions(QWebSocketHandshakeOptions)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebSocketHandshakeOptions_cref_QWebSocketHandshakeOptions, sizeof(QWebSocketHandshakeOptions), typeid(QWebSocketHandshakeOptions), 0, false, &deleter_QWebSocketHandshakeOptions, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QWebSocketHandshakeOptions
void __qt_destruct_QWebSocketHandshakeOptions(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebSocketHandshakeOptions")
    reinterpret_cast<QWebSocketHandshakeOptions*>(ptr)->~QWebSocketHandshakeOptions();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebSocketHandshakeOptions::operator!=(QWebSocketHandshakeOptions,QWebSocketHandshakeOptions)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_operator_1not_1equal_1native_1cref_1QWebSocketHandshakeOptions__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketHandshakeOptions::operator!=(QWebSocketHandshakeOptions,QWebSocketHandshakeOptions)", __this_nativeId)
        const QWebSocketHandshakeOptions& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QWebSocketHandshakeOptions>(rhs1);
        __java_return_value = (*__qt_this) != __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebSocketHandshakeOptions::operator=(QWebSocketHandshakeOptions)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_assign_1native_1cref_1QWebSocketHandshakeOptions__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketHandshakeOptions::operator=(QWebSocketHandshakeOptions)", __this_nativeId)
        const QWebSocketHandshakeOptions& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QWebSocketHandshakeOptions>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketHandshakeOptions::setSubprotocols(QStringList)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_setSubprotocols_1native_1cref_1QStringList__JLjava_util_Collection_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject protocols0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketHandshakeOptions::setSubprotocols(QStringList)", __this_nativeId)
        const QStringList& __qt_protocols0 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, protocols0);
        __qt_this->setSubprotocols(__qt_protocols0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketHandshakeOptions::subprotocols()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_subprotocols_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketHandshakeOptions::subprotocols()const", __this_nativeId)
        QStringList __qt_return_value = __qt_this->subprotocols();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebSocketHandshakeOptions::swap(QWebSocketHandshakeOptions&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_swap_1native_1ref_1QWebSocketHandshakeOptions__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketHandshakeOptions::swap(QWebSocketHandshakeOptions&)", __this_nativeId)
        QWebSocketHandshakeOptions& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWebSocketHandshakeOptions>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketHandshakeOptions_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebSocketHandshakeOptions *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketHandshakeOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebSocketHandshakeOptions(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebSocketHandshakeOptions>("QWebSocketHandshakeOptions", "io/qt/websockets/QWebSocketHandshakeOptions");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QWebSocketHandshakeOptions, {
        ConstructorInfo(&__qt_construct_QWebSocketHandshakeOptions, nullptr)
       ,ConstructorInfo(&__qt_construct_QWebSocketHandshakeOptions_cref_QWebSocketHandshakeOptions, "Lio/qt/websockets/QWebSocketHandshakeOptions;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebSocketHandshakeOptions);
    registerMetaType<QWebSocketHandshakeOptions>("QWebSocketHandshakeOptions");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
